@@ -1,7 +1,5 @@
 from abc import ABCMeta, abstractmethod
 
-from tensorboardX import SummaryWriter
-
 import datasetinsights.constants as const
 from datasetinsights.io.checkpoint import EstimatorCheckpoint
 from datasetinsights.io.kfp_output import KubeflowPipelineWriter
@@ -35,17 +33,18 @@ def create_estimator(
     # todo this makes it so that we lose the tensorboard
     #  writer of non-master processes which could make debugging harder
 
-    writer = SummaryWriter(tb_log_dir)
     kfp_writer = KubeflowPipelineWriter(
-        filename=kfp_metrics_filename, filepath=kfp_metrics_dir,
+        tb_log_dir=tb_log_dir,
+        filename=kfp_metrics_filename,
+        filepath=kfp_metrics_dir,
     )
+    kfp_writer.create_tb_visualization_json()
     checkpointer = EstimatorCheckpoint(
         estimator_name=name, checkpoint_dir=checkpoint_dir, distributed=False,
     )
 
     return estimators_cls(
         config=config,
-        writer=writer,
         kfp_writer=kfp_writer,
         checkpointer=checkpointer,
         logdir=tb_log_dir,
